@@ -6,7 +6,6 @@
 
 from __future__ import annotations
 
-import functools
 import importlib.resources
 import os
 import sys
@@ -19,12 +18,6 @@ else:
     from typing import Collection, Iterable, Iterator, Mapping, Sequence
 
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    cached_property = lambda x: property(functools.lru_cache(maxsize=None)(x))  # noqa: E731
-
-
 if sys.version_info >= (3, 9):
     def read_binary(package: str, resource: str) -> bytes:
         return importlib.resources.files(package).joinpath(resource).read_bytes()
@@ -49,7 +42,6 @@ if typing.TYPE_CHECKING:
 
 
 __all__ = [
-    'cached_property',
     'read_binary',
     'Collection',
     'Iterable',
